FocusNode class

FocusNode type.

Inheritance
Implementers

Constructors

FocusNode({String? debugLabel, FocusOnKeyEvent? onKeyEvent, bool canRequestFocus = true})
Creates a FocusNode.

Properties

canRequestFocus bool
The canRequestFocus value.
getter/setter pair
children Iterable<FocusNode>
The children value.
no setter
debugLabel String?
The debugLabel value.
final
hasFocus bool
The hasFocus value.
no setter
hasFocusedChild bool
The hasFocusedChild value.
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether at least one listener is registered.
no setterinherited
hasPrimaryFocus bool
The hasPrimaryFocus value.
no setter
isAttached bool
The isAttached value.
no setter
isDisposed bool
Whether this notifier has been disposed.
no setterinherited
onKeyEvent FocusOnKeyEvent?
The onKeyEvent value.
getter/setter pair
parent FocusNode?
The parent value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register listener for future notifications.
inherited
attach(BuildContext context) FocusAttachment
Runs attach.
detach() → void
Runs detach.
dispose() → void
Runs dispose.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Notifies all registered listeners using a stable snapshot of the listener list.
inherited
removeListener(VoidCallback listener) → void
Remove one registration of listener.
inherited
requestFocus() → void
Runs requestFocus.
toString() String
A string representation of this object.
inherited
unfocus({bool descendants = false}) → void
Runs unfocus.

Operators

operator ==(Object other) bool
The equality operator.
inherited