InputSubscription class

Handle returned from InputManager.onKey, InputManager.onMouse, and InputManager.onPaste. Call cancel to remove the underlying subscription; safe to call multiple times.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Remove this subscription. Idempotent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited