detach method
void
detach()
inherited
Detaches this state from the tree, marking it unmounted.
Implementation
void detach() {
_mounted = false;
_requestRebuild = null;
_context = null;
}
Detaches this state from the tree, marking it unmounted.
void detach() {
_mounted = false;
_requestRebuild = null;
_context = null;
}