width property
The width to give the child, in terminal character cells.
If null, the child's width is left unconstrained.
Implementation
final int? width;
The width to give the child, in terminal character cells.
If null, the child's width is left unconstrained.
final int? width;