ValueNotifier<T> class

A ChangeNotifier that publishes one value.

Inheritance
Implemented types
Implementers

Constructors

ValueNotifier(T _value)
Creates a ValueNotifier with an initial value.

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether at least one listener is registered.
no setterinherited
isDisposed bool
Whether this notifier has been disposed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ↔ T
Current value.
getter/setter pairoverride-getter

Methods

addListener(VoidCallback listener) → void
Register listener for future notifications.
inherited
dispose() → void
Release resources held by this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Notifies all registered listeners using a stable snapshot of the listener list.
inherited
removeListener(VoidCallback listener) → void
Remove one registration of listener.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited