Attr class

Attr type.

Constructors

Attr()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

The blink value.
bold → const int
The bold value.
dim → const int
The dim value.
italic → const int
The italic value.
reverse → const int
The reverse value.
strike → const int
The strike value.
underline → const int
The underline value.