BoxOptions class

BoxOptions type.

Constructors

BoxOptions({BorderSides sides = const BorderSides(), bool fill = false, String? title, TextAlignment titleAlignment = TextAlignment.left, List<int>? borderChars})
Creates a BoxOptions.
const

Properties

borderChars List<int>?
The borderChars value.
final
fill bool
The fill value.
final
hashCode int
The hash code for this object.
no setterinherited
packedOptions int
The packedOptions value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sides BorderSides
The sides value.
final
title String?
The title value.
final
titleAlignment TextAlignment
The titleAlignment value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited