OpenTuiLibraryLoadException class final

Thrown when the explicit development native-library override cannot load.

Implemented types

Constructors

OpenTuiLibraryLoadException(String message)
Creates a library load exception.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Failure details.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited