clear method

void clear(
  1. Color bg
)

Clears the entire buffer to a uniform background color.

This efficiently resets all cells in the buffer, setting their background colors and clearing any existing characters and formatting.

Example:

buffer.clear(Color.black); // Clear to black background
buffer.clear(Color.transparent); // Clear to transparent

Implementation

void clear(Color bg) {
  _checkValid();
  _bindings.bufferClear(_ptr, bg);
}