owner property
Object?
get
owner
The object that currently owns the cursor, or null when no owner has claimed it.
Implementation
Object? get owner => _owner;
The object that currently owns the cursor, or null when no owner has claimed it.
Object? get owner => _owner;