hideCursor method
void
hideCursor()
Hides the cursor by setting it invisible at position (0, 0).
Implementation
void hideCursor() {
setCursorPosition(0, 0, visible: false);
}
Hides the cursor by setting it invisible at position (0, 0).
void hideCursor() {
setCursorPosition(0, 0, visible: false);
}