DirectBufferAccess class

Direct access to Buffer internal arrays for performance-critical operations

Constructors

DirectBufferAccess({required Uint32List chars, required Float32List foregrounds, required Float32List backgrounds, required Uint8List attributes, required int width, required int height})
Creates a DirectBufferAccess.
const

Properties

attributes Uint8List
Text attributes bitmask for each cell.
final
backgrounds Float32List
Background Color channels packed as four floats per cell (RGBA).
final
chars Uint32List
Unicode code points for each cell in row-major order.
final
foregrounds Float32List
Foreground Color channels packed as four floats per cell (RGBA).
final
hashCode int
The hash code for this object.
no setterinherited
height int
Height of the buffer in cells.
final
length int
Get buffer length (width * height)
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
Width of the buffer in cells.
final

Methods

getAttributes(int x, int y) int
Get text attributes at the specified coordinates
getBackground(int x, int y) Color
Get background color at the specified coordinates
getChar(int x, int y) String
Get a character at the specified coordinates
getForeground(int x, int y) Color
Get foreground color at the specified coordinates
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAttributes(int x, int y, int attr) → void
Set text attributes at the specified coordinates
setBackground(int x, int y, Color color) → void
Set background color at the specified coordinates
setChar(int x, int y, String char) → void
Set a character at the specified coordinates
setForeground(int x, int y, Color color) → void
Set foreground color at the specified coordinates
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited