FrameCallback typedef
FrameCallback =
void Function()
Signature for callbacks invoked when a frame is scheduled.
Implementation
typedef FrameCallback = void Function();
Signature for callbacks invoked when a frame is scheduled.
typedef FrameCallback = void Function();