HitTestResult class final

Result of a render-tree hit test.

Constructors

HitTestResult()

Properties

hashCode int
The hash code for this object.
no setterinherited
path List<HitTestEntry>
Hit-test path from topmost leaf target toward its ancestors.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(HitTestEntry entry) → void
Add entry to the path.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited