path property
Hit-test path from topmost leaf target toward its ancestors.
Implementation
final List<HitTestEntry> path = <HitTestEntry>[];
Hit-test path from topmost leaf target toward its ancestors.
final List<HitTestEntry> path = <HitTestEntry>[];