handleEvent abstract method
Handle event at this target using the resolved hit-test entry.
Implementation
void handleEvent(MouseEvent event, HitTestEntry entry);
Handle event at this target using the resolved hit-test entry.
void handleEvent(MouseEvent event, HitTestEntry entry);