KeyboardSupport extension

Kitty keyboard protocol methods added to Renderer.

on

Methods

disableKittyKeyboard() → void

Available on Renderer, provided by the KeyboardSupport extension

Disables the Kitty keyboard protocol and reverts to standard terminal key reporting.
enableKittyKeyboard({int flags = KittyFlags.disambiguateEscapeCodes}) → void

Available on Renderer, provided by the KeyboardSupport extension

Enables the Kitty keyboard protocol with the given flags.