MultiChildRenderObjectWidget class abstract

Abstract base class for RenderObjectWidgets with multiple children

Inheritance
Implementers

Constructors

MultiChildRenderObjectWidget({Key? key, List<Widget> children = const <Widget>[]})
Creates a render-object widget with the given children.
const

Properties

children List<Widget>
The widgets below this widget in the tree
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how this widget replaces another of the same type.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() MultiChildRenderObjectElement
Create the appropriate Element for this RenderObjectWidget
override
createRenderObject(BuildContext context) RenderObject
Create the RenderObject for this widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRenderObject(BuildContext context, covariant RenderObject renderObject) → void
Update the RenderObject with new configuration
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited