unmount method
Removes this element and its descendants from the tree permanently.
Implementation
@override
void unmount() {
_renderObject?.detach();
detachRenderObject();
_renderObject = null;
super.unmount();
}
Removes this element and its descendants from the tree permanently.
@override
void unmount() {
_renderObject?.detach();
detachRenderObject();
_renderObject = null;
super.unmount();
}