pipelineOwner property
PipelineOwner?
get
pipelineOwner
inherited
The pipeline owner this render object is attached to, if any.
Implementation
PipelineOwner? get pipelineOwner => _pipelineOwner;
The pipeline owner this render object is attached to, if any.
PipelineOwner? get pipelineOwner => _pipelineOwner;