RenderParagraph class

RenderObject that lays out inline spans and records text paint commands.

Inheritance

Constructors

RenderParagraph({required InlineSpan text, TextStyle style = const TextStyle(), TextAlignment alignment = TextAlignment.left, int? maxLines, bool softWrap = true, TextOverflow overflow = TextOverflow.clip, TextHighlight? selection})
Creates a render paragraph.

Properties

alignment TextAlignment
How the text should be aligned within its bounds.
getter/setter pair
children List<RenderObject>
Child RenderObjects
finalinherited
debugNeedsLayout bool
Whether this render object is waiting for layout.
no setterinherited
debugNeedsPaint bool
Whether this render object is waiting for paint.
no setterinherited
debugTextLayout TextLayout?
Last computed text layout.
no setter
hashCode int
The hash code for this object.
no setterinherited
height int
Height in terminal cells, assigned during layout.
getter/setter pairinherited
maxLines int?
The maxLines value.
getter/setter pair
overflow TextOverflow
The overflow value.
getter/setter pair
parent RenderObject?
Parent RenderObject in the tree
getter/setter pairinherited
pipelineOwner → PipelineOwner?
The pipeline owner this render object is attached to, if any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection TextHighlight?
The selection value.
getter/setter pair
size Size
The current size of this box, or Size.zero if not laid out
getter/setter pairinherited
softWrap bool
The softWrap value.
getter/setter pair
style TextStyle
Root style used by unstyled spans.
getter/setter pair
text InlineSpan
The inline span tree to render.
getter/setter pair
width int
Width in terminal cells, assigned during layout.
getter/setter pairinherited
x int
Horizontal position in terminal cells, relative to the parent.
getter/setter pairinherited
y int
Vertical position in terminal cells, relative to the parent.
getter/setter pairinherited

Methods

adoptChild(RenderObject child) → void
Add a child to this render object
inherited
attach(PipelineOwner owner) → void
Attach this render object and its existing children to owner.
inherited
detach() → void
Called when the render object is detached from the render tree.
override
dropChild(RenderObject child) → void
Remove a child from this render object
inherited
getConstraintsForChild(RenderBox child, BoxConstraints constraints) BoxConstraints
Get the constraints that should be applied to children
inherited
hitTest(HitTestResult result, Offset position) bool
Hit-test this render object using position in local coordinates.
inherited
hitTestChildren(HitTestResult result, Offset position) bool
Hit-test children in reverse paint order.
inherited
hitTestSelf(Offset position) bool
Whether this box should add itself to a hit-test path.
inherited
layout(Constraints constraints) → void
Entry point for layout.
inherited
markNeedsLayout() → void
Mark this render object as needing layout and paint.
inherited
markNeedsPaint() → void
Mark this render object as needing paint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset) → void
Default paint implementation.
override
performBoxLayout(BoxConstraints constraints) → void
Perform layout with typed box constraints
override
performLayout(Constraints constraints) → void
Perform layout with box constraints
inherited
positionChild(RenderBox child, int x, int y) → void
Position a child within this box
inherited
toString() String
A string representation of this object.
override
visitChildren(void visitor(RenderObject child)) → void
Visit all children with a callback
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited