RenderPositionedBox class
A render object that positions its child within the available space according to an alignment.
This is the render object used by Align widgets to position their children without relying on Container widgets, avoiding circular dependencies.
- Inheritance
-
- Object
- RenderObject
- RenderBox
- RenderPositionedBox
- Mixed-in types
Constructors
- RenderPositionedBox({required Alignment alignment, RenderBox? child})
- Create a positioned box render object
Properties
- alignment ↔ Alignment
-
Get the current alignment
getter/setter pair
- child → RenderBox?
-
Get the child
no setter
-
children
→ List<
RenderObject> -
Child RenderObjects
finalinherited
- debugNeedsLayout → bool
-
Whether this render object is waiting for layout.
no setterinherited
- debugNeedsPaint → bool
-
Whether this render object is waiting for paint.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
Height in terminal cells, assigned during layout.
getter/setter pairinherited
- parent ↔ RenderObject?
-
Parent RenderObject in the tree
getter/setter pairinherited
- pipelineOwner → PipelineOwner?
-
The pipeline owner this render object is attached to, if any.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size ↔ Size
-
The current size of this box, or Size.zero if not laid out
getter/setter pairinherited
- width ↔ int
-
Width in terminal cells, assigned during layout.
getter/setter pairinherited
- x ↔ int
-
Horizontal position in terminal cells, relative to the parent.
getter/setter pairinherited
- y ↔ int
-
Vertical position in terminal cells, relative to the parent.
getter/setter pairinherited
Methods
-
adoptChild(
RenderObject child) → void -
Add a child to this render object
inherited
-
attach(
PipelineOwner owner) → void -
Attach this render object and its existing children to
owner.inherited -
detach(
) → void -
Called when the render object is detached from the render tree.
inherited
-
dropChild(
RenderObject child) → void -
Remove a child from this render object
inherited
-
getConstraintsForChild(
RenderBox child, BoxConstraints constraints) → BoxConstraints -
Get the constraints that should be applied to children
inherited
-
hitTest(
HitTestResult result, Offset position) → bool -
Hit-test this render object using
positionin local coordinates.inherited -
hitTestChildren(
HitTestResult result, Offset position) → bool -
Hit-test children in reverse paint order.
inherited
-
hitTestSelf(
Offset position) → bool -
Whether this box should add itself to a hit-test path.
inherited
-
layout(
Constraints constraints) → void -
Entry point for layout.
inherited
-
markNeedsLayout(
) → void -
Mark this render object as needing layout and paint.
inherited
-
markNeedsPaint(
) → void -
Mark this render object as needing paint.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset offset) → void -
Default paint implementation.
override
-
performBoxLayout(
BoxConstraints constraints) → void -
Perform layout with typed box constraints
override
-
performLayout(
Constraints constraints) → void -
Perform layout with box constraints
inherited
-
positionChild(
RenderBox child, int x, int y) → void -
Position a child within this box
inherited
-
setChild(
RenderObject? newChild) → void -
Set the child render object. Idempotent: passing the current child or
one already adopted as this object's child is a no-op.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
updateChild(
RenderObject? current, RenderObject? next) → RenderObject? -
Drop
currentand adoptnext, returningnextas the new child.inherited -
visitChildren(
void visitor(RenderObject child)) → void -
Visit all children with a callback
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited