detach method
Called when the render object is detached from the render tree.
Subclasses can override to release resources or unregister handlers.
Implementation
@override
void detach() {
_cursorController.hideCursorFor(this);
super.detach();
}
Called when the render object is detached from the render tree.
Subclasses can override to release resources or unregister handlers.
@override
void detach() {
_cursorController.hideCursorFor(this);
super.detach();
}