mount method
Inserts this element into the tree under parent and builds it.
Implementation
@override
void mount(Element? parent, BuildOwner owner) {
super.mount(parent, owner);
_updateChild(widget.child);
}
Inserts this element into the tree under parent and builds it.
@override
void mount(Element? parent, BuildOwner owner) {
super.mount(parent, owner);
_updateChild(widget.child);
}