unmount method
Removes this element and its descendants from the tree permanently.
Implementation
@override
void unmount() {
_detachChildRenderObject();
_child?.unmount();
_child = null;
children.clear();
super.unmount();
}
Removes this element and its descendants from the tree permanently.
@override
void unmount() {
_detachChildRenderObject();
_child?.unmount();
_child = null;
children.clear();
super.unmount();
}