unmount method
Removes this element and its descendants from the tree permanently.
Implementation
@override
void unmount() {
_state.deactivate();
_state.detach();
super.unmount();
_state.dispose();
}
Removes this element and its descendants from the tree permanently.
@override
void unmount() {
_state.deactivate();
_state.detach();
super.unmount();
_state.dispose();
}