setCell method

void setCell(
  1. int index,
  2. String char,
  3. Color fg,
  4. Color bg,
  5. int attributes,
)

Sets the cell at index to the given character, colors, and attributes.

Implementation

void setCell(int index, String char, Color fg, Color bg, int attributes) {
  _checkNotDisposed();
  final charCode = char.isNotEmpty ? char.runes.first : 0;
  _bindings.textBufferSetCell(_ptr, index, charCode, fg, bg, attributes);
}