SingleTickerProviderStateMixin<T extends StatefulWidget> mixin
SingleTickerProviderStateMixin mixin.
- Superclass constraints
- State<
T>
- State<
- Implemented types
Properties
- context → BuildContext
-
The BuildContext this state was attached with.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mounted → bool
-
Whether this state is currently attached to the tree.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widget → T
-
The current widget configuration this state is bound to.
no setterinherited
Methods
-
attach(
T widget, BuildContext context, void requestRebuild()) → void -
Binds this state to its widget, context, and rebuild callback.
inherited
-
build(
BuildContext context) → Widget -
Describes the part of the UI represented by this state.
inherited
-
createTicker(
TickerCallback onTick, {String? debugLabel}) → Ticker -
Runs createTicker.
override
-
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
detach(
) → void -
Detaches this state from the tree, marking it unmounted.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant T oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
override
-
initState(
) → void -
Called when this object is inserted into the tree.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setState(
VoidCallback fn) → void -
Applies
fnand schedules a rebuild.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateWidget(
T newWidget) → void -
Rebinds this state to
newWidget, invoking didUpdateWidget.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited