Ticker class
Ticker type.
Properties
- debugLabel → String?
-
The debugLabel value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
The isDisposed value.
no setter
- isTicking → bool
-
The isTicking value.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Runs dispose.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
start(
) → void - Runs start.
-
stop(
) → void - Runs stop.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited