BorderSides class

BorderSides type.

Constructors

BorderSides({bool top = true, bool right = true, bool bottom = true, bool left = true})
Creates a BorderSides.
const

Properties

bottom bool
The bottom value.
final
hashCode int
The hash code for this object.
no setterinherited
left bool
The left value.
final
packed int
The packed value.
no setter
The right value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top bool
The top value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited