OpenTuiAbiMismatchException class final
Thrown when the loaded OpenTUI native library does not match Dart's ABI.
- Implemented types
Constructors
- OpenTuiAbiMismatchException({required int expected, required int? found, required String buildInfo, String? details})
- Creates an ABI mismatch exception.
Properties
- buildInfo → String
-
Native build metadata reported by the library.
final
- details → String?
-
Lower-level failure details.
final
- expected → int
-
ABI version required by this Dart package.
final
- found → int?
-
ABI version reported by the native library, or null if unavailable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited