FlexChildData class
Data for each child in a flex layout
Constructors
- FlexChildData({int? flex, FlexFit? fit})
- Creates a FlexChildData.
Properties
- fit ↔ FlexFit?
-
How to size the child in the main axis if it's flexible
getter/setter pair
- flex ↔ int?
-
The flex factor to use for this child
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited