FocusAttachment class
FocusAttachment type.
Properties
- element → Element?
-
The element value.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAttached → bool
-
The isAttached value.
no setter
- isScope → bool
-
The isScope value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
BuildContext context) → void - Runs attach.
-
detach(
) → void - Runs detach.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reparent(
BuildContext context) → void - Runs reparent.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited