HitTestEntry class final
A target and target-local position produced by hit testing.
Constructors
- HitTestEntry(HitTestTarget target, Offset localPosition)
-
Creates a hit-test path entry.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- localPosition → Offset
-
Position in target's local coordinate space.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → HitTestTarget
-
Target that should receive a pointer event.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited