setChild abstract method
Replace this object's single render child.
Implementations must be idempotent: passing the current child or a render object that is already adopted as a child of this parent must be a no-op.
Implementation
void setChild(RenderObject? child);