RenderTextArea class
RenderBox behind TextArea. Paints the visible window of _lines
and drives cursor visibility. Scroll offsets are computed by the State
before each rebuild — the render object is purely a sink.
Horizontal scroll is in TERMINAL CELLS (so wide CJK glyphs contribute 2 cells), vertical scroll is in lines.
- Inheritance
-
- Object
- RenderObject
- RenderBox
- RenderTextArea
Constructors
-
RenderTextArea({required CursorController cursorController, required List<
String> lines, required int cursorLine, required int cursorColumn, required String? placeholder, required int heightLines, required int? explicitWidth, required Color color, required Color? backgroundColor, required Color cursorColor, required CursorStyle cursorStyle, required bool focused, required int scrollLine, required int scrollCell}) - Creates a RenderTextArea.
Properties
- backgroundColor ← Color?
-
no getter
-
children
→ List<
RenderObject> -
Child RenderObjects
finalinherited
- color ← Color
-
no getter
- cursorColor ← Color
-
no getter
- cursorColumn ← int
-
no getter
- cursorLine ← int
-
no getter
- cursorStyle ← CursorStyle
-
no getter
- debugNeedsLayout → bool
-
Whether this render object is waiting for layout.
no setterinherited
- debugNeedsPaint → bool
-
Whether this render object is waiting for paint.
no setterinherited
- explicitWidth ← int?
-
no getter
- focused ← bool
-
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ int
-
Height in terminal cells, assigned during layout.
getter/setter pairinherited
- heightLines ← int
-
no getter
-
lines
← List<
String> -
no getter
- parent ↔ RenderObject?
-
Parent RenderObject in the tree
getter/setter pairinherited
- pipelineOwner → PipelineOwner?
-
The pipeline owner this render object is attached to, if any.
no setterinherited
- placeholder ← String?
-
no getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollCell ← int
-
no getter
- scrollLine ← int
-
no getter
- size ↔ Size
-
The current size of this box, or Size.zero if not laid out
getter/setter pairinherited
- width ↔ int
-
Width in terminal cells, assigned during layout.
getter/setter pairinherited
- x ↔ int
-
Horizontal position in terminal cells, relative to the parent.
getter/setter pairinherited
- y ↔ int
-
Vertical position in terminal cells, relative to the parent.
getter/setter pairinherited
Methods
-
adoptChild(
RenderObject child) → void -
Add a child to this render object
inherited
-
attach(
PipelineOwner owner) → void -
Attach this render object and its existing children to
owner.inherited -
detach(
) → void -
Called when the render object is detached from the render tree.
override
-
dropChild(
RenderObject child) → void -
Remove a child from this render object
inherited
-
getConstraintsForChild(
RenderBox child, BoxConstraints constraints) → BoxConstraints -
Get the constraints that should be applied to children
inherited
-
hitTest(
HitTestResult result, Offset position) → bool -
Hit-test this render object using
positionin local coordinates.inherited -
hitTestChildren(
HitTestResult result, Offset position) → bool -
Hit-test children in reverse paint order.
inherited
-
hitTestSelf(
Offset position) → bool -
Whether this box should add itself to a hit-test path.
inherited
-
layout(
Constraints constraints) → void -
Entry point for layout.
inherited
-
markNeedsLayout(
) → void -
Mark this render object as needing layout and paint.
inherited
-
markNeedsPaint(
) → void -
Mark this render object as needing paint.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset offset) → void -
Default paint implementation.
override
-
performBoxLayout(
BoxConstraints constraints) → void -
Perform layout with typed box constraints
override
-
performLayout(
Constraints constraints) → void -
Perform layout with box constraints
inherited
-
positionChild(
RenderBox child, int x, int y) → void -
Position a child within this box
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitChildren(
void visitor(RenderObject child)) → void -
Visit all children with a callback
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited