setCell method
Sets the cell at index to the given character, colors, and attributes.
Implementation
void setCell(int index, String char, Color fg, Color bg, int attributes) {
_checkNotDisposed();
final charCode = char.isNotEmpty ? char.runes.first : 0;
_bindings.textBufferSetCell(_ptr, index, charCode, fg, bg, attributes);
}